@@ -25,7 +25,7 @@ Usage::
     list_keys_paginator: ListKeysPaginator = client.get_paginator("list_keys")
     ```
 """
-from mypy_boto3_kms.client import KMSClient, KMSClient as Client
+from mypy_boto3_kms.client import KMSClient
 from mypy_boto3_kms.paginator import (
     ListAliasesPaginator,
     ListGrantsPaginator,
@@ -33,6 +33,8 @@ from mypy_boto3_kms.paginator import (
     ListKeysPaginator,
 )
 
+Client = KMSClient
+
 
 __all__ = (
     "Client",
